@@ -2,7 +2,6 @@
 import os
 import sys
 
-from test.test_utils import MockWorkspace
 import pytest
 
 from pyls import uris
@@ -80,12 +79,12 @@ def test_symbols_all_scopes(config, workspace):
 
 
 @pytest.mark.skipif(PY2 or not LINUX or not CI, reason="tested on linux and python 3 only")
-def test_symbols_all_scopes_with_jedi_environment(config):
-    doc = Document(DOC_URI, MockWorkspace(), DOC)
+def test_symbols_all_scopes_with_jedi_environment(workspace):
+    doc = Document(DOC_URI, workspace, DOC)
 
     # Update config extra environment
     env_path = '/tmp/pyenv/bin/python'
-    config.update({'plugins': {'jedi': {'environment': env_path}}})
-    doc.update_config(config)
-    symbols = pyls_document_symbols(config, doc)
+    settings = {'pyls': {'plugins': {'jedi': {'environment': env_path}}}}
+    doc.update_config(settings)
+    symbols = pyls_document_symbols(doc._config, doc)
     helper_check_symbols_all_scope(symbols)
